@@ -18,7 +18,7 @@
 #' pprf.crab <- PPforest(data = crab, class = 'Type',
 #'  std = FALSE, size.tr = 2/3, m = 100, size.p = .4, PPmethod = 'LDA', parallel = TRUE )
 #'  
-#' trees_pred(pprf.crab, xnew = pprf.crab$test ,paralle = TRUE)
+#' trees_pred(pprf.crab, xnew = pprf.crab$test ,parallel = TRUE)
 #' }
 trees_pred <- function(object, xnew, parallel = FALSE, cores = 2, rule = 1) {
 
@@ -27,7 +27,7 @@ trees_pred <- function(object, xnew, parallel = FALSE, cores = 2, rule = 1) {
          doParallel::registerDoParallel(cores)
           
         }
-        if (class(object) == "PPforest") {
+        if (inherits(object,"PPforest")) {
             votes <-  plyr::ldply(object[[8]], function(x) as.numeric(PPforest::PPclassify2(Tree.result = x, 
                 test.data = xnew, Rule = rule)[[2]]), .parallel = parallel)[, -1]
          
